# coding: utf-8

# flake8: noqa

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.3.9821"

# import apis into sdk package
from ourskyai_sda_api.api.default_api import DefaultApi

# import ApiClient
from ourskyai_sda_api.api_response import ApiResponse
from ourskyai_sda_api.api_client import ApiClient
from ourskyai_sda_api.configuration import Configuration
from ourskyai_sda_api.exceptions import OpenApiException
from ourskyai_sda_api.exceptions import ApiTypeError
from ourskyai_sda_api.exceptions import ApiValueError
from ourskyai_sda_api.exceptions import ApiKeyError
from ourskyai_sda_api.exceptions import ApiAttributeError
from ourskyai_sda_api.exceptions import ApiException

# import models into sdk package
from ourskyai_sda_api.models.astrometric_offsets import AstrometricOffsets
from ourskyai_sda_api.models.empty_success import EmptySuccess
from ourskyai_sda_api.models.filter_type import FilterType
from ourskyai_sda_api.models.fits_header import FitsHeader
from ourskyai_sda_api.models.image_set_type import ImageSetType
from ourskyai_sda_api.models.location import Location
from ourskyai_sda_api.models.mount_type import MountType
from ourskyai_sda_api.models.observation_bounding_box import ObservationBoundingBox
from ourskyai_sda_api.models.observation_quality import ObservationQuality
from ourskyai_sda_api.models.observation_result import ObservationResult
from ourskyai_sda_api.models.observation_state import ObservationState
from ourskyai_sda_api.models.orbit_type import OrbitType
from ourskyai_sda_api.models.satellite_target_tracking_status import SatelliteTargetTrackingStatus
from ourskyai_sda_api.models.search_completed_reason import SearchCompletedReason
from ourskyai_sda_api.models.shutter_type import ShutterType
from ourskyai_sda_api.models.successful_create import SuccessfulCreate
from ourskyai_sda_api.models.successful_delete import SuccessfulDelete
from ourskyai_sda_api.models.tracking_type import TrackingType
from ourskyai_sda_api.models.v1_blackout_volume_request import V1BlackoutVolumeRequest
from ourskyai_sda_api.models.v1_create_direct_task_instruction_request import V1CreateDirectTaskInstructionRequest
from ourskyai_sda_api.models.v1_create_image_set_image_request import V1CreateImageSetImageRequest
from ourskyai_sda_api.models.v1_create_image_set_image_response import V1CreateImageSetImageResponse
from ourskyai_sda_api.models.v1_create_image_set_request import V1CreateImageSetRequest
from ourskyai_sda_api.models.v1_create_organization_target_request import V1CreateOrganizationTargetRequest
from ourskyai_sda_api.models.v1_create_satellite_target_request import V1CreateSatelliteTargetRequest
from ourskyai_sda_api.models.v1_create_search_instruction_request import V1CreateSearchInstructionRequest
from ourskyai_sda_api.models.v1_create_survey_instruction_request import V1CreateSurveyInstructionRequest
from ourskyai_sda_api.models.v1_create_webhook_configuration_request import V1CreateWebhookConfigurationRequest
from ourskyai_sda_api.models.v1_create_webhook_test_request import V1CreateWebhookTestRequest
from ourskyai_sda_api.models.v1_get_satellite_targets_response import V1GetSatelliteTargetsResponse
from ourskyai_sda_api.models.v1_ground_station_participant import V1GroundStationParticipant
from ourskyai_sda_api.models.v1_hfr_star import V1HFRStar
from ourskyai_sda_api.models.v1_image_file_type import V1ImageFileType
from ourskyai_sda_api.models.v1_image_metadata import V1ImageMetadata
from ourskyai_sda_api.models.v1_image_rejection_reason import V1ImageRejectionReason
from ourskyai_sda_api.models.v1_image_set import V1ImageSet
from ourskyai_sda_api.models.v1_image_set_image import V1ImageSetImage
from ourskyai_sda_api.models.v1_matched_star import V1MatchedStar
from ourskyai_sda_api.models.v1_node_calibration_result import V1NodeCalibrationResult
from ourskyai_sda_api.models.v1_observation_feature import V1ObservationFeature
from ourskyai_sda_api.models.v1_observation_sequence_result import V1ObservationSequenceResult
from ourskyai_sda_api.models.v1_observation_sequence_result_image_sets_inner import V1ObservationSequenceResultImageSetsInner
from ourskyai_sda_api.models.v1_observation_status import V1ObservationStatus
from ourskyai_sda_api.models.v1_observer_location import V1ObserverLocation
from ourskyai_sda_api.models.v1_organization_target import V1OrganizationTarget
from ourskyai_sda_api.models.v1_pixel_coordinates import V1PixelCoordinates
from ourskyai_sda_api.models.v1_plane_scan_request import V1PlaneScanRequest
from ourskyai_sda_api.models.v1_plate_solve_result import V1PlateSolveResult
from ourskyai_sda_api.models.v1_plate_solve_status import V1PlateSolveStatus
from ourskyai_sda_api.models.v1_point import V1Point
from ourskyai_sda_api.models.v1_predicted_streak_location import V1PredictedStreakLocation
from ourskyai_sda_api.models.v1_put_orbit_provider_tle_request import V1PutOrbitProviderTLERequest
from ourskyai_sda_api.models.v1_ric_volume_search_request import V1RicVolumeSearchRequest
from ourskyai_sda_api.models.v1_sip_coefficients import V1SIPCoefficients
from ourskyai_sda_api.models.v1_satellite_calibration_family import V1SatelliteCalibrationFamily
from ourskyai_sda_api.models.v1_satellite_potential import V1SatellitePotential
from ourskyai_sda_api.models.v1_satellite_target import V1SatelliteTarget
from ourskyai_sda_api.models.v1_search_instruction import V1SearchInstruction
from ourskyai_sda_api.models.v1_search_instruction_step import V1SearchInstructionStep
from ourskyai_sda_api.models.v1_state_vector import V1StateVector
from ourskyai_sda_api.models.v1_survey_instruction import V1SurveyInstruction
from ourskyai_sda_api.models.v1_survey_instruction_step import V1SurveyInstructionStep
from ourskyai_sda_api.models.v1_target_correlation import V1TargetCorrelation
from ourskyai_sda_api.models.v1_tdm import V1Tdm
from ourskyai_sda_api.models.v1_time_tagged_ra_dec import V1TimeTaggedRaDec
from ourskyai_sda_api.models.v1_track import V1Track
from ourskyai_sda_api.models.v1_transformation import V1Transformation
from ourskyai_sda_api.models.v1_update_email_configuration_request import V1UpdateEmailConfigurationRequest
from ourskyai_sda_api.models.v1_update_organization_target_request import V1UpdateOrganizationTargetRequest
from ourskyai_sda_api.models.v1_update_satellite_target_request import V1UpdateSatelliteTargetRequest
from ourskyai_sda_api.models.v1_update_webhook_configuration_request import V1UpdateWebhookConfigurationRequest
from ourskyai_sda_api.models.v1_webhook_configuration import V1WebhookConfiguration
from ourskyai_sda_api.models.v1_webhook_log import V1WebhookLog
from ourskyai_sda_api.models.v2_search import V2Search
from ourskyai_sda_api.models.weather_condition import WeatherCondition
from ourskyai_sda_api.models.webhook_auth_type import WebhookAuthType
from ourskyai_sda_api.models.webhook_event import WebhookEvent



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from ourskyai_sda_api.models.v1_satellite_calibration_family import V1SatelliteCalibrationFamily

class V1NodeCalibrationResult(BaseModel):
    """
    V1NodeCalibrationResult
    """
    id: StrictStr = Field(...)
    node_id: StrictStr = Field(..., alias="nodeId")
    target_id: StrictStr = Field(..., alias="targetId")
    image_id: StrictStr = Field(..., alias="imageId")
    calculated_ra_radians: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="calculatedRaRadians", description="The right ascension of the center of the extracted streak, in radians")
    calculated_dec_radians: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="calculatedDecRadians", description="The declination of the center of the extracted streak, in radians")
    ground_truth_ra_radians: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="groundTruthRaRadians", description="Ground truth right ascension in radians, from SP3 file")
    ground_truth_dec_radians: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="groundTruthDecRadians", description="Ground truth declination in radians, from SP3 file")
    ra_error_arc_seconds: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="raErrorArcSeconds", description="Calculated error in RA, in arc-seconds")
    dec_error_arc_seconds: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="decErrorArcSeconds", description="Calculated error in Dec, in arc-seconds")
    total_error_arc_seconds: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="totalErrorArcSeconds", description="Total error in RA/Dec, in arc-seconds")
    center_time: datetime = Field(..., alias="centerTime")
    calibration_family: V1SatelliteCalibrationFamily = Field(..., alias="calibrationFamily")
    sp3_file: StrictStr = Field(..., alias="sp3File")
    created_at: datetime = Field(..., alias="createdAt")
    __properties = ["id", "nodeId", "targetId", "imageId", "calculatedRaRadians", "calculatedDecRadians", "groundTruthRaRadians", "groundTruthDecRadians", "raErrorArcSeconds", "decErrorArcSeconds", "totalErrorArcSeconds", "centerTime", "calibrationFamily", "sp3File", "createdAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1NodeCalibrationResult:
        """Create an instance of V1NodeCalibrationResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1NodeCalibrationResult:
        """Create an instance of V1NodeCalibrationResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1NodeCalibrationResult.parse_obj(obj)

        _obj = V1NodeCalibrationResult.parse_obj({
            "id": obj.get("id"),
            "node_id": obj.get("nodeId"),
            "target_id": obj.get("targetId"),
            "image_id": obj.get("imageId"),
            "calculated_ra_radians": obj.get("calculatedRaRadians"),
            "calculated_dec_radians": obj.get("calculatedDecRadians"),
            "ground_truth_ra_radians": obj.get("groundTruthRaRadians"),
            "ground_truth_dec_radians": obj.get("groundTruthDecRadians"),
            "ra_error_arc_seconds": obj.get("raErrorArcSeconds"),
            "dec_error_arc_seconds": obj.get("decErrorArcSeconds"),
            "total_error_arc_seconds": obj.get("totalErrorArcSeconds"),
            "center_time": obj.get("centerTime"),
            "calibration_family": obj.get("calibrationFamily"),
            "sp3_file": obj.get("sp3File"),
            "created_at": obj.get("createdAt")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, conlist

class V1Transformation(BaseModel):
    """
    Plate to catplate transform with 3rd-order distortion  # noqa: E501
    """
    a: Union[StrictFloat, StrictInt] = Field(..., description="Affine transformation coefficient")
    b: Union[StrictFloat, StrictInt] = Field(..., description="Affine transformation coefficient")
    c: Union[StrictFloat, StrictInt] = Field(..., description="Affine transformation coefficient")
    d: Union[StrictFloat, StrictInt] = Field(..., description="Affine transformation coefficient")
    u0: Union[StrictFloat, StrictInt] = Field(..., description="Horizontal offset for the affine transformation")
    v0: Union[StrictFloat, StrictInt] = Field(..., description="Vertical offset for the affine transformation")
    alpha: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="Scale")
    beta: Union[StrictFloat, StrictInt] = Field(..., description="Stretch")
    theta: Union[StrictFloat, StrictInt] = Field(..., description="Rotation")
    gamma: Union[StrictFloat, StrictInt] = Field(..., description="Skew")
    eps_x: Union[StrictFloat, StrictInt] = Field(..., alias="epsX", description="3rd-order plate distortion, X-direction")
    eps_y: Union[StrictFloat, StrictInt] = Field(..., alias="epsY", description="3rd-order plate distortion, Y-direction")
    ra_cen: Union[StrictFloat, StrictInt] = Field(..., alias="raCen", description="The reference RA and Dec, in radians, at U = 0, V = 0")
    dec_cen: Union[StrictFloat, StrictInt] = Field(..., alias="decCen", description="The reference RA and Dec, in radians, at U = 0, V = 0")
    px: Union[StrictFloat, StrictInt] = Field(..., description="The number of plate pixels in the X and Y directions. The following coordinate transforms use normalized plate coordinates X/Norm, Y/Norm, where Norm is sqrt(Px^2 + Py^2)/2")
    py: Union[StrictFloat, StrictInt] = Field(..., description="The number of plate pixels in the X and Y directions. The following coordinate transforms use normalized plate coordinates X/Norm, Y/Norm, where Norm is sqrt(Px^2 + Py^2)/2")
    u_coef: conlist(Union[StrictFloat, StrictInt]) = Field(..., alias="uCoef", description="The U-coefficients of the full N-th order match, if available. UCoef(0..NumCoef)")
    v_coef: conlist(Union[StrictFloat, StrictInt]) = Field(..., alias="vCoef", description="The V-coefficients of the full N-th order match, if available. VCoef(0..NumCoef)")
    x_coef: conlist(Union[StrictFloat, StrictInt]) = Field(..., alias="xCoef", description="The X-coefficients of the full N-th order match, if available. XCoef(0..NumCoef)")
    y_coef: conlist(Union[StrictFloat, StrictInt]) = Field(..., alias="yCoef", description="The Y-coefficients of the full N-th order match, if available. YCoef(0..NumCoef)")
    num_coef: StrictInt = Field(..., alias="numCoef", description="The number of coefficients + 1. 0 if there is no high-order match")
    fit_error_radians: Union[StrictFloat, StrictInt] = Field(..., alias="fitErrorRadians", description="The RMS fit error, in radians, for the simple affine + third-order distortion transform")
    fit_error_pix: Union[StrictFloat, StrictInt] = Field(..., alias="fitErrorPix", description="The RMS fit error, in pixels, for the simple affine + third-order distortion transform")
    fit_error3_radians: Union[StrictFloat, StrictInt] = Field(..., alias="fitError3Radians", description="The RMS fit error, in radians, for the full third-order transform")
    fit_error3_pix: Union[StrictFloat, StrictInt] = Field(..., alias="fitError3Pix", description="The RMS fit error, in pixels, for the full third-order transform")
    stretch: Union[StrictFloat, StrictInt] = Field(..., description="The difference in scale values between the X and Y axes, used to test the match geometry")
    skew: Union[StrictFloat, StrictInt] = Field(..., description="The image skew, used to test the match geometry")
    scale: Union[StrictFloat, StrictInt] = Field(..., description="The matched image scale, in pixels per radian")
    rotation: Union[StrictFloat, StrictInt] = Field(..., description="The image rotation, in degrees, agrees with PinPoint")
    __properties = ["a", "b", "c", "d", "u0", "v0", "alpha", "beta", "theta", "gamma", "epsX", "epsY", "raCen", "decCen", "px", "py", "uCoef", "vCoef", "xCoef", "yCoef", "numCoef", "fitErrorRadians", "fitErrorPix", "fitError3Radians", "fitError3Pix", "stretch", "skew", "scale", "rotation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Transformation:
        """Create an instance of V1Transformation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Transformation:
        """Create an instance of V1Transformation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1Transformation.parse_obj(obj)

        _obj = V1Transformation.parse_obj({
            "a": obj.get("a"),
            "b": obj.get("b"),
            "c": obj.get("c"),
            "d": obj.get("d"),
            "u0": obj.get("u0"),
            "v0": obj.get("v0"),
            "alpha": obj.get("alpha"),
            "beta": obj.get("beta"),
            "theta": obj.get("theta"),
            "gamma": obj.get("gamma"),
            "eps_x": obj.get("epsX"),
            "eps_y": obj.get("epsY"),
            "ra_cen": obj.get("raCen"),
            "dec_cen": obj.get("decCen"),
            "px": obj.get("px"),
            "py": obj.get("py"),
            "u_coef": obj.get("uCoef"),
            "v_coef": obj.get("vCoef"),
            "x_coef": obj.get("xCoef"),
            "y_coef": obj.get("yCoef"),
            "num_coef": obj.get("numCoef"),
            "fit_error_radians": obj.get("fitErrorRadians"),
            "fit_error_pix": obj.get("fitErrorPix"),
            "fit_error3_radians": obj.get("fitError3Radians"),
            "fit_error3_pix": obj.get("fitError3Pix"),
            "stretch": obj.get("stretch"),
            "skew": obj.get("skew"),
            "scale": obj.get("scale"),
            "rotation": obj.get("rotation")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_image_metadata import V1ImageMetadata  # noqa: E501

class TestV1ImageMetadata(unittest.TestCase):
    """V1ImageMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1ImageMetadata:
        """Test V1ImageMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1ImageMetadata`
        """
        model = V1ImageMetadata()  # noqa: E501
        if include_optional:
            return V1ImageMetadata(
                id = '',
                image_id = '',
                plate_solve_result = ourskyai_sda_api.models.v1_plate_solve_result.V1PlateSolveResult(
                    status = 'MATCH_FOUND', 
                    matched_stars = [
                        ourskyai_sda_api.models.v1_matched_star.V1MatchedStar(
                            x_centroid = 1.337, 
                            y_centroid = 1.337, 
                            sequence_number = 56, 
                            magnitude = 1.337, 
                            ra_rad = 1.337, 
                            dec_rad = 1.337, 
                            catalog_offset_rad = 1.337, 
                            catalog_offset_magnitude = 1.337, 
                            flux = 56, 
                            hfr = 1.337, )
                        ], 
                    pixel_width = 56, 
                    pixel_height = 56, 
                    number_matched_stars = 56, 
                    center_right_ascension_radians = 1.337, 
                    center_declination_radians = 1.337, 
                    x_size_radians = 1.337, 
                    y_size_radians = 1.337, 
                    is_matched = True, 
                    transformation = ourskyai_sda_api.models.v1_transformation.V1Transformation(
                        a = 1.337, 
                        b = 1.337, 
                        c = 1.337, 
                        d = 1.337, 
                        u0 = 1.337, 
                        v0 = 1.337, 
                        alpha = 1.337, 
                        beta = 1.337, 
                        theta = 1.337, 
                        gamma = 1.337, 
                        eps_x = 1.337, 
                        eps_y = 1.337, 
                        ra_cen = 1.337, 
                        dec_cen = 1.337, 
                        px = 1.337, 
                        py = 1.337, 
                        u_coef = [
                            1.337
                            ], 
                        v_coef = [
                            1.337
                            ], 
                        x_coef = [
                            1.337
                            ], 
                        y_coef = [
                            1.337
                            ], 
                        num_coef = 56, 
                        fit_error_radians = 1.337, 
                        fit_error_pix = 1.337, 
                        fit_error3_radians = 1.337, 
                        fit_error3_pix = 1.337, 
                        stretch = 1.337, 
                        skew = 1.337, 
                        scale = 1.337, 
                        rotation = 1.337, ), ),
                input_stars = [
                    ourskyai_sda_api.models.v1_hfr_star.V1HFRStar(
                        coordinates = ourskyai_sda_api.models.v1_pixel_coordinates.V1PixelCoordinates(
                            x = 1.337, 
                            y = 1.337, ), 
                        hfr = 1.337, 
                        flux = 56, )
                    ],
                sip_coefficients = ourskyai_sda_api.models.v1_sip_coefficients.V1SIPCoefficients(
                    order = 56, 
                    a = [
                        [
                            1.337
                            ]
                        ], 
                    b = [
                        [
                            1.337
                            ]
                        ], 
                    cd1_1 = 1.337, 
                    cd1_2 = 1.337, 
                    cd2_1 = 1.337, 
                    cd2_2 = 1.337, 
                    coordinate_reference_pixel_x = 1.337, 
                    coordinate_reference_pixel_y = 1.337, 
                    coordinate_reference_ra_degrees = 1.337, 
                    coordinate_reference_dec_degrees = 1.337, ),
                photometric_zero_point = 1.337,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return V1ImageMetadata(
                id = '',
                image_id = '',
                plate_solve_result = ourskyai_sda_api.models.v1_plate_solve_result.V1PlateSolveResult(
                    status = 'MATCH_FOUND', 
                    matched_stars = [
                        ourskyai_sda_api.models.v1_matched_star.V1MatchedStar(
                            x_centroid = 1.337, 
                            y_centroid = 1.337, 
                            sequence_number = 56, 
                            magnitude = 1.337, 
                            ra_rad = 1.337, 
                            dec_rad = 1.337, 
                            catalog_offset_rad = 1.337, 
                            catalog_offset_magnitude = 1.337, 
                            flux = 56, 
                            hfr = 1.337, )
                        ], 
                    pixel_width = 56, 
                    pixel_height = 56, 
                    number_matched_stars = 56, 
                    center_right_ascension_radians = 1.337, 
                    center_declination_radians = 1.337, 
                    x_size_radians = 1.337, 
                    y_size_radians = 1.337, 
                    is_matched = True, 
                    transformation = ourskyai_sda_api.models.v1_transformation.V1Transformation(
                        a = 1.337, 
                        b = 1.337, 
                        c = 1.337, 
                        d = 1.337, 
                        u0 = 1.337, 
                        v0 = 1.337, 
                        alpha = 1.337, 
                        beta = 1.337, 
                        theta = 1.337, 
                        gamma = 1.337, 
                        eps_x = 1.337, 
                        eps_y = 1.337, 
                        ra_cen = 1.337, 
                        dec_cen = 1.337, 
                        px = 1.337, 
                        py = 1.337, 
                        u_coef = [
                            1.337
                            ], 
                        v_coef = [
                            1.337
                            ], 
                        x_coef = [
                            1.337
                            ], 
                        y_coef = [
                            1.337
                            ], 
                        num_coef = 56, 
                        fit_error_radians = 1.337, 
                        fit_error_pix = 1.337, 
                        fit_error3_radians = 1.337, 
                        fit_error3_pix = 1.337, 
                        stretch = 1.337, 
                        skew = 1.337, 
                        scale = 1.337, 
                        rotation = 1.337, ), ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testV1ImageMetadata(self):
        """Test V1ImageMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1ImageRejectionReason(str, Enum):
    """
    V1ImageRejectionReason
    """

    """
    allowed enum values
    """
    TARGET_NOT_FOUND = 'TARGET_NOT_FOUND'
    RATE_TARGET_NOT_FOUND = 'RATE_TARGET_NOT_FOUND'
    RATE_PLATE_SOLVE_FAILURE = 'RATE_PLATE_SOLVE_FAILURE'
    STREAK_DETECTION_FAILURE = 'STREAK_DETECTION_FAILURE'
    PLATE_SOLVE_FAILURE = 'PLATE_SOLVE_FAILURE'
    PLATE_SOLVE_NOT_ENOUGH_STARS_FAILURE = 'PLATE_SOLVE_NOT_ENOUGH_STARS_FAILURE'
    PLATE_SOLVE_NO_SOLUTION_FAILURE = 'PLATE_SOLVE_NO_SOLUTION_FAILURE'
    CROP_IMAGE_FAILURE = 'CROP_IMAGE_FAILURE'
    COSMETIC_CORRECTION_FAILURE = 'COSMETIC_CORRECTION_FAILURE'
    GRADIENT_REMOVAL_FAILURE = 'GRADIENT_REMOVAL_FAILURE'
    CATMAG_FAILURE = 'CATMAG_FAILURE'
    IMAGE_QUALITY_TOO_LOW = 'IMAGE_QUALITY_TOO_LOW'
    OBSERVATION_NOT_FOUND = 'OBSERVATION_NOT_FOUND'
    NODE_NOT_FOUND = 'NODE_NOT_FOUND'
    CAMERA_NOT_FOUND = 'CAMERA_NOT_FOUND'
    OTA_NOT_FOUND = 'OTA_NOT_FOUND'
    TLE_NOT_EXTRACTED = 'TLE_NOT_EXTRACTED'
    FAILED_TO_LOAD = 'FAILED_TO_LOAD'
    GPS_ERROR = 'GPS_ERROR'
    MUTEX_TIMEOUT = 'MUTEX_TIMEOUT'
    AWAIT_TIMEOUT = 'AWAIT_TIMEOUT'
    CATALOG_COMPARE_ERROR = 'CATALOG_COMPARE_ERROR'
    SAVE_FAILURE = 'SAVE_FAILURE'
    RATE_CATALOG_COMPARE_ERROR = 'RATE_CATALOG_COMPARE_ERROR'
    MISSING_IMG_WIDTH_HEADER = 'MISSING_IMG_WIDTH_HEADER'
    UNKNOWN_ERROR = 'UNKNOWN_ERROR'

    @classmethod
    def from_json(cls, json_str: str) -> V1ImageRejectionReason:
        """Create an instance of V1ImageRejectionReason from a JSON string"""
        return V1ImageRejectionReason(json.loads(json_str))





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, conlist

class V1SIPCoefficients(BaseModel):
    """
    V1SIPCoefficients
    """
    order: StrictInt = Field(..., description="Order of the SIP transformation")
    a: conlist(conlist(Union[StrictFloat, StrictInt])) = Field(..., alias="A", description="Forward SIP coefficients matrix A")
    b: conlist(conlist(Union[StrictFloat, StrictInt])) = Field(..., alias="B", description="Forward SIP coefficients matrix B")
    cd1_1: Union[StrictFloat, StrictInt] = Field(..., alias="CD1_1", description="Coordinate description matrix element (1,1) - maps pixel coordinates to sky coordinates in degrees, encapsulating scale, rotation and skew")
    cd1_2: Union[StrictFloat, StrictInt] = Field(..., alias="CD1_2", description="Coordinate description matrix element (1,2) - maps pixel coordinates to sky coordinates in degrees, encapsulating scale, rotation and skew")
    cd2_1: Union[StrictFloat, StrictInt] = Field(..., alias="CD2_1", description="Coordinate description matrix element (2,1) - maps pixel coordinates to sky coordinates in degrees, encapsulating scale, rotation and skew")
    cd2_2: Union[StrictFloat, StrictInt] = Field(..., alias="CD2_2", description="Coordinate description matrix element (2,2) - maps pixel coordinates to sky coordinates in degrees, encapsulating scale, rotation and skew")
    coordinate_reference_pixel_x: Union[StrictFloat, StrictInt] = Field(..., alias="coordinateReferencePixelX", description="X coordinate of the reference pixel")
    coordinate_reference_pixel_y: Union[StrictFloat, StrictInt] = Field(..., alias="coordinateReferencePixelY", description="Y coordinate of the reference pixel")
    coordinate_reference_ra_degrees: Union[StrictFloat, StrictInt] = Field(..., alias="coordinateReferenceRADegrees", description="Right ascension of the reference coordinate in degrees")
    coordinate_reference_dec_degrees: Union[StrictFloat, StrictInt] = Field(..., alias="coordinateReferenceDecDegrees", description="Declination of the reference coordinate in degrees")
    __properties = ["order", "A", "B", "CD1_1", "CD1_2", "CD2_1", "CD2_2", "coordinateReferencePixelX", "coordinateReferencePixelY", "coordinateReferenceRADegrees", "coordinateReferenceDecDegrees"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1SIPCoefficients:
        """Create an instance of V1SIPCoefficients from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1SIPCoefficients:
        """Create an instance of V1SIPCoefficients from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1SIPCoefficients.parse_obj(obj)

        _obj = V1SIPCoefficients.parse_obj({
            "order": obj.get("order"),
            "a": obj.get("A"),
            "b": obj.get("B"),
            "cd1_1": obj.get("CD1_1"),
            "cd1_2": obj.get("CD1_2"),
            "cd2_1": obj.get("CD2_1"),
            "cd2_2": obj.get("CD2_2"),
            "coordinate_reference_pixel_x": obj.get("coordinateReferencePixelX"),
            "coordinate_reference_pixel_y": obj.get("coordinateReferencePixelY"),
            "coordinate_reference_ra_degrees": obj.get("coordinateReferenceRADegrees"),
            "coordinate_reference_dec_degrees": obj.get("coordinateReferenceDecDegrees")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_observation_sequence_result_image_sets_inner import V1ObservationSequenceResultImageSetsInner  # noqa: E501

class TestV1ObservationSequenceResultImageSetsInner(unittest.TestCase):
    """V1ObservationSequenceResultImageSetsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1ObservationSequenceResultImageSetsInner:
        """Test V1ObservationSequenceResultImageSetsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1ObservationSequenceResultImageSetsInner`
        """
        model = V1ObservationSequenceResultImageSetsInner()  # noqa: E501
        if include_optional:
            return V1ObservationSequenceResultImageSetsInner(
                id = '',
                node_id = '',
                covariance = [
                    [
                        1.337
                        ]
                    ],
                observation_results = [
                    ourskyai_sda_api.models.observation_result.observationResult(
                        image_id = '', 
                        astrometric_offsets = ourskyai_sda_api.models.astrometric_offsets.astrometricOffsets(
                            ra_plate_solve_offset_average = 1.337, 
                            ra_plate_solve_offset_std_dev = 1.337, 
                            dec_plate_solve_offset_average = 1.337, 
                            dec_plate_solve_offset_std_dev = 1.337, 
                            fwhm_std_dev = 1.337, 
                            fwhm_average = 1.337, ), 
                        image_url = '', 
                        jpg_url = '', 
                        ra = 1.337, 
                        dec = 1.337, 
                        corrected_ra = 1.337, 
                        corrected_dec = 1.337, 
                        bounding_box = ourskyai_sda_api.models.observation_bounding_box.observationBoundingBox(
                            start_x = 56, 
                            start_y = 56, 
                            end_x = 56, 
                            end_y = 56, ), 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timing_accuracy = 1.337, 
                        apparent_magnitude = 1.337, 
                        solar_phase_angle = 1.337, 
                        solar_eq_phase_angle = 1.337, 
                        geolat = 1.337, 
                        geolon = 1.337, 
                        distance_from_prediction = 1.337, 
                        features = [
                            ourskyai_sda_api.models.v1_observation_feature.V1ObservationFeature(
                                corrected_ra = 1.337, 
                                corrected_dec = 1.337, 
                                ra = 1.337, 
                                dec = 1.337, 
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                apparent_magnitude = 1.337, 
                                apparent_magnitude_is_calibrated = True, 
                                distance_from_prediction = 1.337, 
                                target_correlations = [
                                    ourskyai_sda_api.models.v1_target_correlation.V1TargetCorrelation(
                                        target_id = '', 
                                        ra = 1.337, 
                                        dec = 1.337, 
                                        streak_length = 1.337, 
                                        distance_from_streak = 1.337, 
                                        angle_from_streak = 1.337, )
                                    ], )
                            ], )
                    ],
                observation_quality = ourskyai_sda_api.models.observation_quality.observationQuality(
                    line_fit_offset_std_dev = 1.337, 
                    distance_from_prediction_average = 1.337, 
                    distance_from_prediction_line_fit_slope = 1.337, 
                    distance_from_prediction_line_fit_std_dev = 1.337, )
            )
        else:
            return V1ObservationSequenceResultImageSetsInner(
                id = '',
                node_id = '',
                covariance = [
                    [
                        1.337
                        ]
                    ],
                observation_results = [
                    ourskyai_sda_api.models.observation_result.observationResult(
                        image_id = '', 
                        astrometric_offsets = ourskyai_sda_api.models.astrometric_offsets.astrometricOffsets(
                            ra_plate_solve_offset_average = 1.337, 
                            ra_plate_solve_offset_std_dev = 1.337, 
                            dec_plate_solve_offset_average = 1.337, 
                            dec_plate_solve_offset_std_dev = 1.337, 
                            fwhm_std_dev = 1.337, 
                            fwhm_average = 1.337, ), 
                        image_url = '', 
                        jpg_url = '', 
                        ra = 1.337, 
                        dec = 1.337, 
                        corrected_ra = 1.337, 
                        corrected_dec = 1.337, 
                        bounding_box = ourskyai_sda_api.models.observation_bounding_box.observationBoundingBox(
                            start_x = 56, 
                            start_y = 56, 
                            end_x = 56, 
                            end_y = 56, ), 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timing_accuracy = 1.337, 
                        apparent_magnitude = 1.337, 
                        solar_phase_angle = 1.337, 
                        solar_eq_phase_angle = 1.337, 
                        geolat = 1.337, 
                        geolon = 1.337, 
                        distance_from_prediction = 1.337, 
                        features = [
                            ourskyai_sda_api.models.v1_observation_feature.V1ObservationFeature(
                                corrected_ra = 1.337, 
                                corrected_dec = 1.337, 
                                ra = 1.337, 
                                dec = 1.337, 
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                apparent_magnitude = 1.337, 
                                apparent_magnitude_is_calibrated = True, 
                                distance_from_prediction = 1.337, 
                                target_correlations = [
                                    ourskyai_sda_api.models.v1_target_correlation.V1TargetCorrelation(
                                        target_id = '', 
                                        ra = 1.337, 
                                        dec = 1.337, 
                                        streak_length = 1.337, 
                                        distance_from_streak = 1.337, 
                                        angle_from_streak = 1.337, )
                                    ], )
                            ], )
                    ],
        )
        """

    def testV1ObservationSequenceResultImageSetsInner(self):
        """Test V1ObservationSequenceResultImageSetsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class V1WebhookLog(BaseModel):
    """
    V1WebhookLog
    """
    id: StrictStr = Field(...)
    webhook_id: StrictStr = Field(..., alias="webhookId")
    status: StrictStr = Field(...)
    status_code: Optional[StrictInt] = Field(None, alias="statusCode")
    created_at: datetime = Field(..., alias="createdAt")
    log: Optional[StrictStr] = Field(None, description="The full log message")
    __properties = ["id", "webhookId", "status", "statusCode", "createdAt", "log"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1WebhookLog:
        """Create an instance of V1WebhookLog from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1WebhookLog:
        """Create an instance of V1WebhookLog from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1WebhookLog.parse_obj(obj)

        _obj = V1WebhookLog.parse_obj({
            "id": obj.get("id"),
            "webhook_id": obj.get("webhookId"),
            "status": obj.get("status"),
            "status_code": obj.get("statusCode"),
            "created_at": obj.get("createdAt"),
            "log": obj.get("log")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class WeatherCondition(str, Enum):
    """
    WeatherCondition
    """

    """
    allowed enum values
    """
    THUNDERSTORM = 'THUNDERSTORM'
    DRIZZLE = 'DRIZZLE'
    RAIN = 'RAIN'
    SNOW = 'SNOW'
    ATMOSPHERE = 'ATMOSPHERE'
    CLEAR = 'CLEAR'
    CLOUDS = 'CLOUDS'

    @classmethod
    def from_json(cls, json_str: str) -> WeatherCondition:
        """Create an instance of WeatherCondition from a JSON string"""
        return WeatherCondition(json.loads(json_str))





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, conlist
from ourskyai_sda_api.models.observation_bounding_box import ObservationBoundingBox
from ourskyai_sda_api.models.v1_target_correlation import V1TargetCorrelation

class V1ObservationFeature(BaseModel):
    """
    Observation Feature  # noqa: E501
    """
    corrected_ra: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="correctedRa", description="EME2000 right ascension, corrected for stellar aberration [degrees]")
    corrected_dec: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="correctedDec", description="EME2000 declination, corrected for stellar aberration [degrees]")
    ra: Union[StrictFloat, StrictInt] = Field(..., description="the right ascension in degrees in EME2000 frame, not corrected for stellar aberration")
    dec: Union[StrictFloat, StrictInt] = Field(..., description="the declination in degrees in EME2000 frame, not corrected for stellar aberration")
    timestamp: datetime = Field(...)
    bounding_box: Optional[ObservationBoundingBox] = Field(None, alias="boundingBox")
    apparent_magnitude: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="apparentMagnitude", description="BETA: the apparent magnitude of the target at the time of the observation")
    apparent_magnitude_is_calibrated: Optional[StrictBool] = Field(None, alias="apparentMagnitudeIsCalibrated", description="indicates if the apparentMagnitude is calibrated against stars in the image, if enough were identified. If false, the apparentMagnitude is simply a flux conversion, still useful for light curves")
    distance_from_prediction: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="distanceFromPrediction", description="The distance from the predicted location in arcseconds (using SGP4 propagation)")
    target_correlations: Optional[conlist(V1TargetCorrelation)] = Field(None, alias="targetCorrelations")
    __properties = ["correctedRa", "correctedDec", "ra", "dec", "timestamp", "boundingBox", "apparentMagnitude", "apparentMagnitudeIsCalibrated", "distanceFromPrediction", "targetCorrelations"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ObservationFeature:
        """Create an instance of V1ObservationFeature from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of bounding_box
        if self.bounding_box:
            _dict['boundingBox'] = self.bounding_box.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in target_correlations (list)
        _items = []
        if self.target_correlations:
            for _item in self.target_correlations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['targetCorrelations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ObservationFeature:
        """Create an instance of V1ObservationFeature from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ObservationFeature.parse_obj(obj)

        _obj = V1ObservationFeature.parse_obj({
            "corrected_ra": obj.get("correctedRa"),
            "corrected_dec": obj.get("correctedDec"),
            "ra": obj.get("ra"),
            "dec": obj.get("dec"),
            "timestamp": obj.get("timestamp"),
            "bounding_box": ObservationBoundingBox.from_dict(obj.get("boundingBox")) if obj.get("boundingBox") is not None else None,
            "apparent_magnitude": obj.get("apparentMagnitude"),
            "apparent_magnitude_is_calibrated": obj.get("apparentMagnitudeIsCalibrated"),
            "distance_from_prediction": obj.get("distanceFromPrediction"),
            "target_correlations": [V1TargetCorrelation.from_dict(_item) for _item in obj.get("targetCorrelations")] if obj.get("targetCorrelations") is not None else None
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ourskyai_sda_api.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_uncorrelated_tracks(self) -> None:
        """Test case for get_uncorrelated_tracks

        Get uncorrelated tracks collected by the network.  # noqa: E501
        """
        pass

    def test_v1_create_blackout_volume(self) -> None:
        """Test case for v1_create_blackout_volume

        """
        pass

    def test_v1_create_direct_task_instruction(self) -> None:
        """Test case for v1_create_direct_task_instruction

        """
        pass

    def test_v1_create_image_set(self) -> None:
        """Test case for v1_create_image_set

        """
        pass

    def test_v1_create_image_set_image(self) -> None:
        """Test case for v1_create_image_set_image

        """
        pass

    def test_v1_create_organization_target(self) -> None:
        """Test case for v1_create_organization_target

        """
        pass

    def test_v1_create_satellite_target(self) -> None:
        """Test case for v1_create_satellite_target

        """
        pass

    def test_v1_create_search_instruction(self) -> None:
        """Test case for v1_create_search_instruction

        """
        pass

    def test_v1_create_survey_instruction(self) -> None:
        """Test case for v1_create_survey_instruction

        """
        pass

    def test_v1_create_webhook_configuration(self) -> None:
        """Test case for v1_create_webhook_configuration

        """
        pass

    def test_v1_create_webhook_test(self) -> None:
        """Test case for v1_create_webhook_test

        """
        pass

    def test_v1_delete_blackout_volume(self) -> None:
        """Test case for v1_delete_blackout_volume

        """
        pass

    def test_v1_delete_direct_task_instruction(self) -> None:
        """Test case for v1_delete_direct_task_instruction

        """
        pass

    def test_v1_delete_image_set(self) -> None:
        """Test case for v1_delete_image_set

        """
        pass

    def test_v1_delete_image_set_image(self) -> None:
        """Test case for v1_delete_image_set_image

        """
        pass

    def test_v1_delete_organization_target(self) -> None:
        """Test case for v1_delete_organization_target

        """
        pass

    def test_v1_delete_search_instruction(self) -> None:
        """Test case for v1_delete_search_instruction

        """
        pass

    def test_v1_delete_survey_instruction(self) -> None:
        """Test case for v1_delete_survey_instruction

        """
        pass

    def test_v1_delete_webhook_configuration(self) -> None:
        """Test case for v1_delete_webhook_configuration

        """
        pass

    def test_v1_get_image_metadata(self) -> None:
        """Test case for v1_get_image_metadata

        """
        pass

    def test_v1_get_image_set(self) -> None:
        """Test case for v1_get_image_set

        """
        pass

    def test_v1_get_image_set_image(self) -> None:
        """Test case for v1_get_image_set_image

        """
        pass

    def test_v1_get_image_set_images(self) -> None:
        """Test case for v1_get_image_set_images

        """
        pass

    def test_v1_get_image_sets(self) -> None:
        """Test case for v1_get_image_sets

        """
        pass

    def test_v1_get_node_properties(self) -> None:
        """Test case for v1_get_node_properties

        """
        pass

    def test_v1_get_node_satellite_calibrations(self) -> None:
        """Test case for v1_get_node_satellite_calibrations

        """
        pass

    def test_v1_get_observation_features(self) -> None:
        """Test case for v1_get_observation_features

        """
        pass

    def test_v1_get_observation_sequence_result(self) -> None:
        """Test case for v1_get_observation_sequence_result

        """
        pass

    def test_v1_get_observation_sequence_results(self) -> None:
        """Test case for v1_get_observation_sequence_results

        """
        pass

    def test_v1_get_observation_statuses(self) -> None:
        """Test case for v1_get_observation_statuses

        """
        pass

    def test_v1_get_organization_satellite_potentials(self) -> None:
        """Test case for v1_get_organization_satellite_potentials

        """
        pass

    def test_v1_get_organization_target(self) -> None:
        """Test case for v1_get_organization_target

        """
        pass

    def test_v1_get_organization_targets(self) -> None:
        """Test case for v1_get_organization_targets

        """
        pass

    def test_v1_get_satellite_potentials(self) -> None:
        """Test case for v1_get_satellite_potentials

        """
        pass

    def test_v1_get_satellite_target(self) -> None:
        """Test case for v1_get_satellite_target

        """
        pass

    def test_v1_get_satellite_targets(self) -> None:
        """Test case for v1_get_satellite_targets

        """
        pass

    def test_v1_get_search_instructions(self) -> None:
        """Test case for v1_get_search_instructions

        """
        pass

    def test_v1_get_state_vectors(self) -> None:
        """Test case for v1_get_state_vectors

        """
        pass

    def test_v1_get_survey_instructions(self) -> None:
        """Test case for v1_get_survey_instructions

        """
        pass

    def test_v1_get_tdm(self) -> None:
        """Test case for v1_get_tdm

        """
        pass

    def test_v1_get_tdms(self) -> None:
        """Test case for v1_get_tdms

        """
        pass

    def test_v1_get_webhook_configurations(self) -> None:
        """Test case for v1_get_webhook_configurations

        """
        pass

    def test_v1_get_webhook_logs(self) -> None:
        """Test case for v1_get_webhook_logs

        """
        pass

    def test_v1_put_orbit_provider_tle_orbit(self) -> None:
        """Test case for v1_put_orbit_provider_tle_orbit

        """
        pass

    def test_v1_update_email_configuration(self) -> None:
        """Test case for v1_update_email_configuration

        """
        pass

    def test_v1_update_organization_target(self) -> None:
        """Test case for v1_update_organization_target

        """
        pass

    def test_v1_update_satellite_target(self) -> None:
        """Test case for v1_update_satellite_target

        """
        pass

    def test_v1_update_webhook_configuration(self) -> None:
        """Test case for v1_update_webhook_configuration

        """
        pass

    def test_v2_create_plane_scan(self) -> None:
        """Test case for v2_create_plane_scan

        """
        pass

    def test_v2_create_ric_volume_search(self) -> None:
        """Test case for v2_create_ric_volume_search

        """
        pass

    def test_v2_delete_plane_scan(self) -> None:
        """Test case for v2_delete_plane_scan

        """
        pass

    def test_v2_delete_ric_volume_search(self) -> None:
        """Test case for v2_delete_ric_volume_search

        """
        pass

    def test_v2_get_search(self) -> None:
        """Test case for v2_get_search

        """
        pass

    def test_v2_get_searches(self) -> None:
        """Test case for v2_get_searches

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, conlist
from ourskyai_sda_api.models.v1_matched_star import V1MatchedStar
from ourskyai_sda_api.models.v1_plate_solve_status import V1PlateSolveStatus
from ourskyai_sda_api.models.v1_transformation import V1Transformation

class V1PlateSolveResult(BaseModel):
    """
    V1PlateSolveResult
    """
    status: Optional[V1PlateSolveStatus] = None
    matched_stars: Optional[conlist(V1MatchedStar)] = Field(None, alias="matchedStars")
    pixel_width: StrictInt = Field(..., alias="pixelWidth", description="The number of pixels in X directions")
    pixel_height: StrictInt = Field(..., alias="pixelHeight", description="The number of pixels in Y directions")
    number_matched_stars: StrictInt = Field(..., alias="numberMatchedStars", description="The number of matched stars")
    center_right_ascension_radians: Union[StrictFloat, StrictInt] = Field(..., alias="centerRightAscensionRadians", description="In radians, the exact RA center when matched")
    center_declination_radians: Union[StrictFloat, StrictInt] = Field(..., alias="centerDeclinationRadians", description="In radians, the exact Dec center when matched")
    x_size_radians: Union[StrictFloat, StrictInt] = Field(..., alias="xSizeRadians", description="The approximate plate size in X-direction, in radians")
    y_size_radians: Union[StrictFloat, StrictInt] = Field(..., alias="ySizeRadians", description="The approximate plate size in Y-direction, in radians")
    is_matched: StrictBool = Field(..., alias="isMatched", description="True if there is a valid plate match")
    transformation: V1Transformation = Field(...)
    __properties = ["status", "matchedStars", "pixelWidth", "pixelHeight", "numberMatchedStars", "centerRightAscensionRadians", "centerDeclinationRadians", "xSizeRadians", "ySizeRadians", "isMatched", "transformation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1PlateSolveResult:
        """Create an instance of V1PlateSolveResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in matched_stars (list)
        _items = []
        if self.matched_stars:
            for _item in self.matched_stars:
                if _item:
                    _items.append(_item.to_dict())
            _dict['matchedStars'] = _items
        # override the default output from pydantic by calling `to_dict()` of transformation
        if self.transformation:
            _dict['transformation'] = self.transformation.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1PlateSolveResult:
        """Create an instance of V1PlateSolveResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1PlateSolveResult.parse_obj(obj)

        _obj = V1PlateSolveResult.parse_obj({
            "status": obj.get("status"),
            "matched_stars": [V1MatchedStar.from_dict(_item) for _item in obj.get("matchedStars")] if obj.get("matchedStars") is not None else None,
            "pixel_width": obj.get("pixelWidth"),
            "pixel_height": obj.get("pixelHeight"),
            "number_matched_stars": obj.get("numberMatchedStars"),
            "center_right_ascension_radians": obj.get("centerRightAscensionRadians"),
            "center_declination_radians": obj.get("centerDeclinationRadians"),
            "x_size_radians": obj.get("xSizeRadians"),
            "y_size_radians": obj.get("ySizeRadians"),
            "is_matched": obj.get("isMatched"),
            "transformation": V1Transformation.from_dict(obj.get("transformation")) if obj.get("transformation") is not None else None
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist
from ourskyai_sda_api.models.v1_hfr_star import V1HFRStar
from ourskyai_sda_api.models.v1_plate_solve_result import V1PlateSolveResult
from ourskyai_sda_api.models.v1_sip_coefficients import V1SIPCoefficients

class V1ImageMetadata(BaseModel):
    """
    V1ImageMetadata
    """
    id: StrictStr = Field(...)
    image_id: StrictStr = Field(..., alias="imageId")
    plate_solve_result: V1PlateSolveResult = Field(..., alias="plateSolveResult")
    input_stars: Optional[conlist(V1HFRStar)] = Field(None, alias="inputStars", description="Extracted star features from the image. Used as inputs to plate solving")
    sip_coefficients: Optional[V1SIPCoefficients] = Field(None, alias="sipCoefficients")
    photometric_zero_point: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="photometricZeroPoint", description="Photometric zero point offset. Add to instrumental magnitude (-2.5*log10(flux)) to get calibrated magnitude in standard photometric system.")
    created_at: datetime = Field(..., alias="createdAt")
    __properties = ["id", "imageId", "plateSolveResult", "inputStars", "sipCoefficients", "photometricZeroPoint", "createdAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ImageMetadata:
        """Create an instance of V1ImageMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of plate_solve_result
        if self.plate_solve_result:
            _dict['plateSolveResult'] = self.plate_solve_result.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in input_stars (list)
        _items = []
        if self.input_stars:
            for _item in self.input_stars:
                if _item:
                    _items.append(_item.to_dict())
            _dict['inputStars'] = _items
        # override the default output from pydantic by calling `to_dict()` of sip_coefficients
        if self.sip_coefficients:
            _dict['sipCoefficients'] = self.sip_coefficients.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ImageMetadata:
        """Create an instance of V1ImageMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ImageMetadata.parse_obj(obj)

        _obj = V1ImageMetadata.parse_obj({
            "id": obj.get("id"),
            "image_id": obj.get("imageId"),
            "plate_solve_result": V1PlateSolveResult.from_dict(obj.get("plateSolveResult")) if obj.get("plateSolveResult") is not None else None,
            "input_stars": [V1HFRStar.from_dict(_item) for _item in obj.get("inputStars")] if obj.get("inputStars") is not None else None,
            "sip_coefficients": V1SIPCoefficients.from_dict(obj.get("sipCoefficients")) if obj.get("sipCoefficients") is not None else None,
            "photometric_zero_point": obj.get("photometricZeroPoint"),
            "created_at": obj.get("createdAt")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_image_rejection_reason import V1ImageRejectionReason  # noqa: E501

class TestV1ImageRejectionReason(unittest.TestCase):
    """V1ImageRejectionReason unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1ImageRejectionReason(self):
        """Test V1ImageRejectionReason"""
        # inst = V1ImageRejectionReason()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class V1RicVolumeSearchRequest(BaseModel):
    """
    Parameters to create a RIC volume search to search for a target - 3-sigma values should be at most 10% of the target's perigee altitude  # noqa: E501
    """
    target_id: StrictStr = Field(..., alias="targetId")
    radial3_sigma_meters: Union[StrictFloat, StrictInt] = Field(..., alias="radial3SigmaMeters", description="The radial 3-sigma uncertainty in meters")
    intrack3_sigma_meters: Union[StrictFloat, StrictInt] = Field(..., alias="intrack3SigmaMeters", description="The intrack 3-sigma uncertainty in meters")
    crosstrack3_sigma_meters: Union[StrictFloat, StrictInt] = Field(..., alias="crosstrack3SigmaMeters", description="The crosstrack 3-sigma uncertainty in meters")
    ric_stdev_epoch: Optional[datetime] = Field(None, alias="ricStdevEpoch", description="The epoch of the RIC standard deviation- if none is provided the current time is used")
    __properties = ["targetId", "radial3SigmaMeters", "intrack3SigmaMeters", "crosstrack3SigmaMeters", "ricStdevEpoch"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1RicVolumeSearchRequest:
        """Create an instance of V1RicVolumeSearchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1RicVolumeSearchRequest:
        """Create an instance of V1RicVolumeSearchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1RicVolumeSearchRequest.parse_obj(obj)

        _obj = V1RicVolumeSearchRequest.parse_obj({
            "target_id": obj.get("targetId"),
            "radial3_sigma_meters": obj.get("radial3SigmaMeters"),
            "intrack3_sigma_meters": obj.get("intrack3SigmaMeters"),
            "crosstrack3_sigma_meters": obj.get("crosstrack3SigmaMeters"),
            "ric_stdev_epoch": obj.get("ricStdevEpoch")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt

class ObservationQuality(BaseModel):
    """
    ObservationQuality
    """
    line_fit_offset_std_dev: Union[StrictFloat, StrictInt] = Field(..., alias="lineFitOffsetStdDev", description="Standard deviation for the line fit of the observation positions over time")
    distance_from_prediction_average: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="distanceFromPredictionAverage", description="Average of the distances beween observation and prediction, in arcsec")
    distance_from_prediction_line_fit_slope: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="distanceFromPredictionLineFitSlope", description="Slope of the linear fit of distances, in arcsec per second")
    distance_from_prediction_line_fit_std_dev: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="distanceFromPredictionLineFitStdDev", description="Standard deviation of the offsets of the linear fit")
    __properties = ["lineFitOffsetStdDev", "distanceFromPredictionAverage", "distanceFromPredictionLineFitSlope", "distanceFromPredictionLineFitStdDev"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ObservationQuality:
        """Create an instance of ObservationQuality from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ObservationQuality:
        """Create an instance of ObservationQuality from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ObservationQuality.parse_obj(obj)

        _obj = ObservationQuality.parse_obj({
            "line_fit_offset_std_dev": obj.get("lineFitOffsetStdDev"),
            "distance_from_prediction_average": obj.get("distanceFromPredictionAverage"),
            "distance_from_prediction_line_fit_slope": obj.get("distanceFromPredictionLineFitSlope"),
            "distance_from_prediction_line_fit_std_dev": obj.get("distanceFromPredictionLineFitStdDev")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator

class V1StateVector(BaseModel):
    """
    State vector representing a satellite's position and velocity in space.  # noqa: E501
    """
    id: StrictStr = Field(..., description="Unique identifier for the state vector.")
    target_id: StrictStr = Field(..., alias="targetId", description="Identifier of the satellite target this state vector belongs to.")
    pos_x: Union[StrictFloat, StrictInt] = Field(..., alias="posX", description="Position in the X direction in meters.")
    pos_y: Union[StrictFloat, StrictInt] = Field(..., alias="posY", description="Position in the Y direction in meters.")
    pos_z: Union[StrictFloat, StrictInt] = Field(..., alias="posZ", description="Position in the Z direction in meters.")
    vel_x: Union[StrictFloat, StrictInt] = Field(..., alias="velX", description="Velocity in the X direction in meters per second.")
    vel_y: Union[StrictFloat, StrictInt] = Field(..., alias="velY", description="Velocity in the Y direction in meters per second.")
    vel_z: Union[StrictFloat, StrictInt] = Field(..., alias="velZ", description="Velocity in the Z direction in meters per second.")
    epoch: datetime = Field(..., description="UTC epoch of the state vector")
    reference_frame: StrictStr = Field(..., alias="referenceFrame")
    drag_coefficient: Union[StrictFloat, StrictInt] = Field(..., alias="dragCoefficient", description="Drag coefficient of the satellite- normalized to a 1m^2 cross-sectional area and a 1kg mass.")
    srp_coefficient: Union[StrictFloat, StrictInt] = Field(..., alias="srpCoefficient", description="Solar radiation pressure coefficient of the satellite- normalized to a 1m^2 cross-sectional area and a 1kg mass.")
    __properties = ["id", "targetId", "posX", "posY", "posZ", "velX", "velY", "velZ", "epoch", "referenceFrame", "dragCoefficient", "srpCoefficient"]

    @validator('reference_frame')
    def reference_frame_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('ECI_J2000', 'ECEF'):
            raise ValueError("must be one of enum values ('ECI_J2000', 'ECEF')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1StateVector:
        """Create an instance of V1StateVector from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1StateVector:
        """Create an instance of V1StateVector from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1StateVector.parse_obj(obj)

        _obj = V1StateVector.parse_obj({
            "id": obj.get("id"),
            "target_id": obj.get("targetId"),
            "pos_x": obj.get("posX"),
            "pos_y": obj.get("posY"),
            "pos_z": obj.get("posZ"),
            "vel_x": obj.get("velX"),
            "vel_y": obj.get("velY"),
            "vel_z": obj.get("velZ"),
            "epoch": obj.get("epoch"),
            "reference_frame": obj.get("referenceFrame"),
            "drag_coefficient": obj.get("dragCoefficient"),
            "srp_coefficient": obj.get("srpCoefficient")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_plate_solve_result import V1PlateSolveResult  # noqa: E501

class TestV1PlateSolveResult(unittest.TestCase):
    """V1PlateSolveResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1PlateSolveResult:
        """Test V1PlateSolveResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1PlateSolveResult`
        """
        model = V1PlateSolveResult()  # noqa: E501
        if include_optional:
            return V1PlateSolveResult(
                status = 'MATCH_FOUND',
                matched_stars = [
                    ourskyai_sda_api.models.v1_matched_star.V1MatchedStar(
                        x_centroid = 1.337, 
                        y_centroid = 1.337, 
                        sequence_number = 56, 
                        magnitude = 1.337, 
                        ra_rad = 1.337, 
                        dec_rad = 1.337, 
                        catalog_offset_rad = 1.337, 
                        catalog_offset_magnitude = 1.337, 
                        flux = 56, 
                        hfr = 1.337, )
                    ],
                pixel_width = 56,
                pixel_height = 56,
                number_matched_stars = 56,
                center_right_ascension_radians = 1.337,
                center_declination_radians = 1.337,
                x_size_radians = 1.337,
                y_size_radians = 1.337,
                is_matched = True,
                transformation = ourskyai_sda_api.models.v1_transformation.V1Transformation(
                    a = 1.337, 
                    b = 1.337, 
                    c = 1.337, 
                    d = 1.337, 
                    u0 = 1.337, 
                    v0 = 1.337, 
                    alpha = 1.337, 
                    beta = 1.337, 
                    theta = 1.337, 
                    gamma = 1.337, 
                    eps_x = 1.337, 
                    eps_y = 1.337, 
                    ra_cen = 1.337, 
                    dec_cen = 1.337, 
                    px = 1.337, 
                    py = 1.337, 
                    u_coef = [
                        1.337
                        ], 
                    v_coef = [
                        1.337
                        ], 
                    x_coef = [
                        1.337
                        ], 
                    y_coef = [
                        1.337
                        ], 
                    num_coef = 56, 
                    fit_error_radians = 1.337, 
                    fit_error_pix = 1.337, 
                    fit_error3_radians = 1.337, 
                    fit_error3_pix = 1.337, 
                    stretch = 1.337, 
                    skew = 1.337, 
                    scale = 1.337, 
                    rotation = 1.337, )
            )
        else:
            return V1PlateSolveResult(
                pixel_width = 56,
                pixel_height = 56,
                number_matched_stars = 56,
                center_right_ascension_radians = 1.337,
                center_declination_radians = 1.337,
                x_size_radians = 1.337,
                y_size_radians = 1.337,
                is_matched = True,
                transformation = ourskyai_sda_api.models.v1_transformation.V1Transformation(
                    a = 1.337, 
                    b = 1.337, 
                    c = 1.337, 
                    d = 1.337, 
                    u0 = 1.337, 
                    v0 = 1.337, 
                    alpha = 1.337, 
                    beta = 1.337, 
                    theta = 1.337, 
                    gamma = 1.337, 
                    eps_x = 1.337, 
                    eps_y = 1.337, 
                    ra_cen = 1.337, 
                    dec_cen = 1.337, 
                    px = 1.337, 
                    py = 1.337, 
                    u_coef = [
                        1.337
                        ], 
                    v_coef = [
                        1.337
                        ], 
                    x_coef = [
                        1.337
                        ], 
                    y_coef = [
                        1.337
                        ], 
                    num_coef = 56, 
                    fit_error_radians = 1.337, 
                    fit_error_pix = 1.337, 
                    fit_error3_radians = 1.337, 
                    fit_error3_pix = 1.337, 
                    stretch = 1.337, 
                    skew = 1.337, 
                    scale = 1.337, 
                    rotation = 1.337, ),
        )
        """

    def testV1PlateSolveResult(self):
        """Test V1PlateSolveResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist, validator
from ourskyai_sda_api.models.v1_point import V1Point

class V1BlackoutVolumeRequest(BaseModel):
    """
    A designated volume of space that is not to be observed.  # noqa: E501
    """
    reference_frame: StrictStr = Field(..., description="The reference frame in which the volume is defined.")
    points: conlist(V1Point) = Field(..., description="The set of 8 points that define the volume, coordinates should be in the selected reference frame.")
    __properties = ["reference_frame", "points"]

    @validator('reference_frame')
    def reference_frame_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('ECI_J2000', 'ECEF'):
            raise ValueError("must be one of enum values ('ECI_J2000', 'ECEF')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1BlackoutVolumeRequest:
        """Create an instance of V1BlackoutVolumeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in points (list)
        _items = []
        if self.points:
            for _item in self.points:
                if _item:
                    _items.append(_item.to_dict())
            _dict['points'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1BlackoutVolumeRequest:
        """Create an instance of V1BlackoutVolumeRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1BlackoutVolumeRequest.parse_obj(obj)

        _obj = V1BlackoutVolumeRequest.parse_obj({
            "reference_frame": obj.get("reference_frame"),
            "points": [V1Point.from_dict(_item) for _item in obj.get("points")] if obj.get("points") is not None else None
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class V1CreateSatelliteTargetRequest(BaseModel):
    """
    V1CreateSatelliteTargetRequest
    """
    tle_name: Optional[StrictStr] = Field(None, alias="tleName")
    tle_line1: Optional[StrictStr] = Field(None, alias="tleLine1")
    tle_line2: Optional[StrictStr] = Field(None, alias="tleLine2")
    linked_satellite_target_id: Optional[StrictStr] = Field(None, alias="linkedSatelliteTargetId", description="The OurSky Satellite Target. When this is specified OurSky will automatically choose the TLE to use based on which target has the newest TLE. The private target or the upstream target")
    mass: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="mass in kilograms")
    coefficient_of_reflection: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="coefficientOfReflection", description="The Cr value used to calculate acceleration due to solar radiation pressure")
    cross_section: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="crossSection", description="cross sectional area in meters^2")
    __properties = ["tleName", "tleLine1", "tleLine2", "linkedSatelliteTargetId", "mass", "coefficientOfReflection", "crossSection"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CreateSatelliteTargetRequest:
        """Create an instance of V1CreateSatelliteTargetRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CreateSatelliteTargetRequest:
        """Create an instance of V1CreateSatelliteTargetRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CreateSatelliteTargetRequest.parse_obj(obj)

        _obj = V1CreateSatelliteTargetRequest.parse_obj({
            "tle_name": obj.get("tleName"),
            "tle_line1": obj.get("tleLine1"),
            "tle_line2": obj.get("tleLine2"),
            "linked_satellite_target_id": obj.get("linkedSatelliteTargetId"),
            "mass": obj.get("mass"),
            "coefficient_of_reflection": obj.get("coefficientOfReflection"),
            "cross_section": obj.get("crossSection")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from ourskyai_sda_api.models.orbit_type import OrbitType
from ourskyai_sda_api.models.satellite_target_tracking_status import SatelliteTargetTrackingStatus

class V1SatelliteTarget(BaseModel):
    """
    Satellite Target  # noqa: E501
    """
    id: StrictStr = Field(...)
    cospar_id: Optional[StrictStr] = Field(None, alias="cosparId")
    norad_id: Optional[StrictStr] = Field(None, alias="noradId")
    orbit_type: OrbitType = Field(..., alias="orbitType")
    tle_epoch: Optional[datetime] = Field(None, alias="tleEpoch")
    tle_name: Optional[StrictStr] = Field(None, alias="tleName")
    tle_line1: Optional[StrictStr] = Field(None, alias="tleLine1")
    tle_line2: Optional[StrictStr] = Field(None, alias="tleLine2")
    tracking_status: Optional[SatelliteTargetTrackingStatus] = Field(None, alias="trackingStatus")
    classification: Optional[StrictStr] = None
    launch_year: Optional[StrictInt] = Field(None, alias="launchYear")
    epoch_year: Optional[StrictInt] = Field(None, alias="epochYear")
    epoch_day: Optional[StrictInt] = Field(None, alias="epochDay")
    mean_motion_first_derivative: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="meanMotionFirstDerivative")
    mean_motion_second_derivative: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="meanMotionSecondDerivative")
    bstar: Optional[Union[StrictFloat, StrictInt]] = None
    ephemeris_type: Optional[StrictInt] = Field(None, alias="ephemerisType")
    element_number: Optional[StrictInt] = Field(None, alias="elementNumber")
    inclination: Optional[Union[StrictFloat, StrictInt]] = None
    raan: Optional[Union[StrictFloat, StrictInt]] = None
    eccentricity: Optional[Union[StrictFloat, StrictInt]] = None
    perigee_argument: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="perigeeArgument")
    mean_anomaly: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="meanAnomaly")
    mean_motion: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="meanMotion")
    revolution_number_at_epoch: Optional[StrictInt] = Field(None, alias="revolutionNumberAtEpoch")
    organization_id: Optional[StrictStr] = Field(None, alias="organizationId")
    coefficient_of_reflection: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="coefficientOfReflection")
    mass: Optional[Union[StrictFloat, StrictInt]] = None
    area: Optional[Union[StrictFloat, StrictInt]] = None
    linked_satellite_target_id: Optional[StrictStr] = Field(None, alias="linkedSatelliteTargetId", description="Linked satellite target id on our system. See [POST /v1/satellite-target](#tag/satellite-targets/POST/v1/satellite-target)")
    orbit_source_id: Optional[StrictStr] = Field(None, alias="orbitSourceId")
    orbit_source_provider_name: Optional[StrictStr] = Field(None, alias="orbitSourceProviderName")
    __properties = ["id", "cosparId", "noradId", "orbitType", "tleEpoch", "tleName", "tleLine1", "tleLine2", "trackingStatus", "classification", "launchYear", "epochYear", "epochDay", "meanMotionFirstDerivative", "meanMotionSecondDerivative", "bstar", "ephemerisType", "elementNumber", "inclination", "raan", "eccentricity", "perigeeArgument", "meanAnomaly", "meanMotion", "revolutionNumberAtEpoch", "organizationId", "coefficientOfReflection", "mass", "area", "linkedSatelliteTargetId", "orbitSourceId", "orbitSourceProviderName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1SatelliteTarget:
        """Create an instance of V1SatelliteTarget from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1SatelliteTarget:
        """Create an instance of V1SatelliteTarget from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1SatelliteTarget.parse_obj(obj)

        _obj = V1SatelliteTarget.parse_obj({
            "id": obj.get("id"),
            "cospar_id": obj.get("cosparId"),
            "norad_id": obj.get("noradId"),
            "orbit_type": obj.get("orbitType"),
            "tle_epoch": obj.get("tleEpoch"),
            "tle_name": obj.get("tleName"),
            "tle_line1": obj.get("tleLine1"),
            "tle_line2": obj.get("tleLine2"),
            "tracking_status": obj.get("trackingStatus"),
            "classification": obj.get("classification"),
            "launch_year": obj.get("launchYear"),
            "epoch_year": obj.get("epochYear"),
            "epoch_day": obj.get("epochDay"),
            "mean_motion_first_derivative": obj.get("meanMotionFirstDerivative"),
            "mean_motion_second_derivative": obj.get("meanMotionSecondDerivative"),
            "bstar": obj.get("bstar"),
            "ephemeris_type": obj.get("ephemerisType"),
            "element_number": obj.get("elementNumber"),
            "inclination": obj.get("inclination"),
            "raan": obj.get("raan"),
            "eccentricity": obj.get("eccentricity"),
            "perigee_argument": obj.get("perigeeArgument"),
            "mean_anomaly": obj.get("meanAnomaly"),
            "mean_motion": obj.get("meanMotion"),
            "revolution_number_at_epoch": obj.get("revolutionNumberAtEpoch"),
            "organization_id": obj.get("organizationId"),
            "coefficient_of_reflection": obj.get("coefficientOfReflection"),
            "mass": obj.get("mass"),
            "area": obj.get("area"),
            "linked_satellite_target_id": obj.get("linkedSatelliteTargetId"),
            "orbit_source_id": obj.get("orbitSourceId"),
            "orbit_source_provider_name": obj.get("orbitSourceProviderName")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_image_set_image import V1ImageSetImage  # noqa: E501

class TestV1ImageSetImage(unittest.TestCase):
    """V1ImageSetImage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1ImageSetImage:
        """Test V1ImageSetImage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1ImageSetImage`
        """
        model = V1ImageSetImage()  # noqa: E501
        if include_optional:
            return V1ImageSetImage(
                id = '',
                thumbnail_url = '',
                image_url = '',
                full_jpg_url = '',
                node_id = '',
                target_id = '',
                ra = 1.337,
                dec = 1.337,
                image_set_id = '',
                dark_calibrated = True,
                flat_calibrated = True,
                bias_calibrated = True,
                fwhm_average = 1.337,
                fwhm_std_dev = 1.337,
                fwhm_angle = 1.337,
                ra_offset = 1.337,
                dec_offset = 1.337,
                total_offset = 1.337,
                total_offset_std_dev = 1.337,
                total_offset_rms = 1.337,
                captured_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                binning = 56,
                exposure_length = 1.337,
                fits_headers = [
                    ourskyai_sda_api.models.fits_header.FitsHeader(
                        key = '', 
                        value = '', )
                    ],
                predicted_streak_location = ourskyai_sda_api.models.v1_predicted_streak_location.V1PredictedStreakLocation(
                    start_x = 1.337, 
                    start_y = 1.337, 
                    end_x = 1.337, 
                    end_y = 1.337, ),
                rejected_reason = 'TARGET_NOT_FOUND'
            )
        else:
            return V1ImageSetImage(
                id = '',
                image_url = '',
                node_id = '',
                image_set_id = '',
                dark_calibrated = True,
                flat_calibrated = True,
                bias_calibrated = True,
                captured_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                exposure_length = 1.337,
                fits_headers = [
                    ourskyai_sda_api.models.fits_header.FitsHeader(
                        key = '', 
                        value = '', )
                    ],
        )
        """

    def testV1ImageSetImage(self):
        """Test V1ImageSetImage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "ourskyai-sda-api"
VERSION = "1.3.9821"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 1.10.5, < 2",
    "aenum"
]

setup(
    name=NAME,
    version=VERSION,
    description="OurSky SDA",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "OurSky SDA"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.
    """,  # noqa: E501
    package_data={"ourskyai_sda_api": ["py.typed"]},
)



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from ourskyai_sda_api.models.tracking_type import TrackingType
from ourskyai_sda_api.models.v1_search_instruction_step import V1SearchInstructionStep

class V1SearchInstruction(BaseModel):
    """
    Search Instruction  # noqa: E501
    """
    id: StrictStr = Field(...)
    node_id: Optional[StrictStr] = Field(None, alias="nodeId")
    target_id: StrictStr = Field(..., alias="targetId")
    tracking_type: TrackingType = Field(..., alias="trackingType")
    steps: conlist(V1SearchInstructionStep) = Field(..., description="Each step indicates an observation attempt at a given distance offset in the local spacecraft frame.  Offset values for each step should always be entered in absolute distance offset from the target's TLE, not relative to the previous step.")
    __properties = ["id", "nodeId", "targetId", "trackingType", "steps"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1SearchInstruction:
        """Create an instance of V1SearchInstruction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in steps (list)
        _items = []
        if self.steps:
            for _item in self.steps:
                if _item:
                    _items.append(_item.to_dict())
            _dict['steps'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1SearchInstruction:
        """Create an instance of V1SearchInstruction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1SearchInstruction.parse_obj(obj)

        _obj = V1SearchInstruction.parse_obj({
            "id": obj.get("id"),
            "node_id": obj.get("nodeId"),
            "target_id": obj.get("targetId"),
            "tracking_type": obj.get("trackingType"),
            "steps": [V1SearchInstructionStep.from_dict(_item) for _item in obj.get("steps")] if obj.get("steps") is not None else None
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_ground_station_participant import V1GroundStationParticipant  # noqa: E501

class TestV1GroundStationParticipant(unittest.TestCase):
    """V1GroundStationParticipant unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1GroundStationParticipant:
        """Test V1GroundStationParticipant
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1GroundStationParticipant`
        """
        model = V1GroundStationParticipant()  # noqa: E501
        if include_optional:
            return V1GroundStationParticipant(
                node_id = '',
                location = ourskyai_sda_api.models.location.Location(
                    latitude = 1.337, 
                    longitude = 1.337, 
                    altitude = 1.337, ),
                megapixels = 1.337,
                shutter_type = 'ROLLING',
                pixel_size_microns = 1.337,
                gps_timestamps = True,
                ota_focal_length_mm = 56,
                ota_aperture_mm = 56,
                mount_type = 'ALT_AZ',
                master_flat = '',
                master_dark = '',
                master_bias = '',
                focuser_travel_distance_mm = 56,
                supported_tracking_modes = [
                    'SIDEREAL'
                    ]
            )
        else:
            return V1GroundStationParticipant(
                node_id = '',
                location = ourskyai_sda_api.models.location.Location(
                    latitude = 1.337, 
                    longitude = 1.337, 
                    altitude = 1.337, ),
                megapixels = 1.337,
                shutter_type = 'ROLLING',
                pixel_size_microns = 1.337,
                gps_timestamps = True,
                ota_focal_length_mm = 56,
                ota_aperture_mm = 56,
                mount_type = 'ALT_AZ',
        )
        """

    def testV1GroundStationParticipant(self):
        """Test V1GroundStationParticipant"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.9821
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist
from ourskyai_sda_api.models.astrometric_offsets import AstrometricOffsets
from ourskyai_sda_api.models.observation_bounding_box import ObservationBoundingBox
from ourskyai_sda_api.models.v1_observation_feature import V1ObservationFeature

class ObservationResult(BaseModel):
    """
    A single observation result. This is a 1:1 mapping with a single image  # noqa: E501
    """
    image_id: StrictStr = Field(..., alias="imageId")
    astrometric_offsets: AstrometricOffsets = Field(..., alias="astrometricOffsets")
    image_url: Optional[StrictStr] = Field(None, alias="imageUrl")
    jpg_url: Optional[StrictStr] = Field(None, alias="jpgUrl")
    ra: Union[StrictFloat, StrictInt] = Field(..., description="The un-corrected apparent right ascension in degrees and EME2000 frame at the ground station")
    dec: Union[StrictFloat, StrictInt] = Field(..., description="The un-corrected apparent declination in degrees and EME2000 frame at the ground station")
    corrected_ra: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="correctedRa", description="The measured right ascension calibrated for stellar aberration in degrees and EME2000 frame")
    corrected_dec: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="correctedDec", description="The measured declination calibrated for stellar aberration in degrees and EME2000 frame")
    bounding_box: Optional[ObservationBoundingBox] = Field(None, alias="boundingBox")
    timestamp: datetime = Field(...)
    timing_accuracy: Union[StrictFloat, StrictInt] = Field(..., alias="timingAccuracy", description="Timestamps for this image are considered to be accurate to within +/- this value in seconds")
    apparent_magnitude: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="apparentMagnitude", description="BETA: the apparent magnitude of the target at the time of the observation")
    solar_phase_angle: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="solarPhaseAngle", description="BETA: the solar phase angle, defined as the angle between the target->observer and target->sun vectors, in degrees at the time of observation")
    solar_eq_phase_angle: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="solarEqPhaseAngle", description="BETA: the solar equatorial phase angle, defined as the solar phase angle in the equatorial plane, in degrees at the time of observation")
    geolat: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="BETA: GEO latitude in degrees, if applicable")
    geolon: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="BETA: GEO longitude in degrees, if applicable")
    distance_from_prediction: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="distanceFromPrediction", description="The distance from the predicted location in arcseconds (using SGP4 propagation)")
    features: Optional[conlist(V1ObservationFeature)] = None
    __properties = ["imageId", "astrometricOffsets", "imageUrl", "jpgUrl", "ra", "dec", "correctedRa", "correctedDec", "boundingBox", "timestamp", "timingAccuracy", "apparentMagnitude", "solarPhaseAngle", "solarEqPhaseAngle", "geolat", "geolon", "distanceFromPrediction", "features"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ObservationResult:
        """Create an instance of ObservationResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of astrometric_offsets
        if self.astrometric_offsets:
            _dict['astrometricOffsets'] = self.astrometric_offsets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bounding_box
        if self.bounding_box:
            _dict['boundingBox'] = self.bounding_box.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in features (list)
        _items = []
        if self.features:
            for _item in self.features:
                if _item:
                    _items.append(_item.to_dict())
            _dict['features'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ObservationResult:
        """Create an instance of ObservationResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ObservationResult.parse_obj(obj)

        _obj = ObservationResult.parse_obj({
            "image_id": obj.get("imageId"),
            "astrometric_offsets": AstrometricOffsets.from_dict(obj.get("astrometricOffsets")) if obj.get("astrometricOffsets") is not None else None,
            "image_url": obj.get("imageUrl"),
            "jpg_url": obj.get("jpgUrl"),
            "ra": obj.get("ra"),
            "dec": obj.get("dec"),
            "corrected_ra": obj.get("correctedRa"),
            "corrected_dec": obj.get("correctedDec"),
            "bounding_box": ObservationBoundingBox.from_dict(obj.get("boundingBox")) if obj.get("boundingBox") is not None else None,
            "timestamp": obj.get("timestamp"),
            "timing_accuracy": obj.get("timingAccuracy"),
            "apparent_magnitude": obj.get("apparentMagnitude"),
            "solar_phase_angle": obj.get("solarPhaseAngle"),
            "solar_eq_phase_angle": obj.get("solarEqPhaseAngle"),
            "geolat": obj.get("geolat"),
            "geolon": obj.get("geolon"),
            "distance_from_prediction": obj.get("distanceFromPrediction"),
            "features": [V1ObservationFeature.from_dict(_item) for _item in obj.get("features")] if obj.get("features") is not None else None
        })
        return _obj


